# =====================================
# generator=datazen
# version=2.1.0
# hash=16d64b8b583d6612bd879395e512162d
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A collection of core Python utilities."
PKG_NAME = "vcorelib"
VERSION = "0.4.1"

DEFAULT_INDENT = 2
DEFAULT_ENCODING = "utf-8"
